@@ -1,4 +1,3 @@
-import builtins
 import importlib.util
 import inspect
 import logging
@@ -10,6 +9,8 @@ from socket import gethostname
 from string import ascii_letters
 from typing import Optional, Type, TypeVar
 
+import functools
+import builtins
 import yaml
 from pydantic import ValidationError
 from pydantic.main import BaseModel
@@ -90,7 +91,6 @@ def settings_module():
     return string("SETTINGS_MODULE", "config")
 
 
-
 def log_level() -> int:
     log_levels = {
         "INFO": logging.INFO,
@@ -122,7 +122,9 @@ def version() -> str:
 def resource() -> str:
     resource = string("AUTH_RESOURCE", "")
     if not resource:
-        resource = gethostname()
+        # in test mode we allow using hostname, to make sure that the CI execution (docker) behaves like the local
+        if testing() or not _inside_docker():
+            resource = gethostname()
     return resource
 
 
@@ -402,13 +404,16 @@ def override_context(**options):
 def override_settings(**options):
     def decorator(x):
         if inspect.isclass(x):
-            class MockedClass(x):
-                def run(self, result=None):
-                    with override_context(**options):
-                        super().run(result)
+            original_run = x.run
 
-            return MockedClass
+            def new_run(inner_self, result=None):
+                with override_context(**options):
+                    original_run(inner_self, result)
+
+            x.run = new_run
+            return x
         elif callable(x):
+            @functools.wraps(x)
             def wrapper(*args, **kwargs):
                 with override_context(**options):
                     x(*args, **kwargs)
@@ -420,7 +425,7 @@ def override_settings(**options):
 
 class GlobalSettings:
     # usual
-    NAME = string("NAME", "om_service_toolazytochange_1")
+    NAME = string("NAME", "om_dev_unnamed_1")
     VERSION = version()
     RESOURCE = resource()
     DEBUG = debug()
@@ -437,11 +442,3 @@ class GlobalSettings:
 
 settings = LazySettings()
 _override_settings = OverrideSettings()
-
-# test settigns for openmodule tests
-NAME = "test"
-RESOURCE = "test-resource"
-VERSION = "test-version"
-random_suffix = "".join(random.choices(ascii_letters, k=10))
-BROKER_SUB = f"inproc://test-sub-{random_suffix}"
-BROKER_PUB = f"inproc://test-pub-{random_suffix}"
