@@ -3,6 +3,7 @@ import threading
 from collections import namedtuple
 from typing import Callable, Dict, Optional, Type
 
+import sentry_sdk
 import zmq
 from pydantic import ValidationError, BaseModel
 from pydantic.main import ROOT_KEY
@@ -48,12 +49,20 @@ class RPCServer(object):
         self.name = config.NAME
         self.sub = get_sub_socket(context, config)
         self.pub = get_pub_socket(context, config)
-        self.resource = config.RESOURCE if filter_resource else None
         self.handlers: Dict[tuple, HandlerEntry] = {}
         self.filters = []
         self.running = True
         self.log = logging.getLogger(self.__class__.__name__)
         self.thread = None
+        self.resource = None
+        if filter_resource:
+            if config.RESOURCE:
+                self.resource = config.RESOURCE
+            else:
+                self.log.error(
+                    "Resource filter is active, but no resource is available. All RPCs requests will be processed. "
+                    "This is ok for debugging / testing containers, but must not happen in production."
+                )
 
     def add_filter(self, filter: Callable[[], bool], channel=None, type=None):
         """
@@ -116,8 +125,9 @@ class RPCServer(object):
         return self.thread
 
     def process_rpc(self, channel, message: RPCRequest) -> Optional[Dict]:
-        if self.resource and self.resource != message.resource:
+        if self.resource and message.resource and self.resource != message.resource:
             return None
+
         handler: HandlerEntry = self.find_handler(channel, message.type)
         if handler:
             try:
