@@ -1,3 +1,5 @@
+import logging
+from socket import gethostname
 from typing import Optional, Dict, Any
 from typing import TYPE_CHECKING
 
@@ -46,8 +48,12 @@ def init_sentry(core: 'OpenModuleCore', extras=None, **kwargs):
     if should_activate_sentry(core.config):
         zmq_transport = ZeroMQTransport(core)
         environment = environment_from_config(core.config)
+        server_name = core.config.RESOURCE
+        if not server_name:
+            core.log.warning("resource not available using hostname instead for sentry tag")
+            server_name = gethostname()
         sentry_sdk.init(
-            dsn=None, release=core.config.VERSION, server_name=core.config.RESOURCE, environment=environment,
+            dsn=None, release=core.config.VERSION, server_name=server_name, environment=environment,
             transport=zmq_transport, **kwargs
         )
 
