@@ -28,7 +28,7 @@ class PresenceListener:
     present_vehicles: Dict[str, Vehicle]
 
     @property
-    def present_vehicle(self) -> Vehicle:
+    def present_vehicle(self) -> Optional[Vehicle]:
         assert self.gate is not None, (
             "`.present_vehicle` may only be used when listening for a specific gate, this presence listener"
             "listens to all gates, please access the present vehicle per gate via `.present_vehicles[gate]`"
