@@ -339,7 +339,7 @@ def fake_config(broker: Optional[TestBroker] = None, **kwargs):
     return config
 
 
-def find_free_port():
+def _find_free_port():
     with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as s:
         s.bind(('127.0.0.1', 0))
         s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
@@ -351,7 +351,7 @@ class _TestRPCRequest(BaseModel):
     we do not want to depend on openmodule, this is a minimal version of the zmq message for the rpc function
     """
     timestamp: float = Field(default_factory=time.time)
-    resource: str = settings.RESOURCE
+    resource: Optional[str] = settings.RESOURCE
     name: str
     type: str
     rpc_id: UUID
@@ -373,16 +373,30 @@ class ZMQTestMixin(TestCase):
 
     def setUp(self):
         super(ZMQTestMixin, self).setUp()
+
         assert self.protocol in ["tcp://", "inproc://"], "only tcp:// and inproc:// protocols are allowed"
-        if self.protocol == "tcp://" and not settings.BROKER_SUB.startswith("tcp"):
-            settings.override(BROKER_SUB=f"tcp://127.0.0.1:{find_free_port()}",
-                              BROKER_PUB=f"tcp://127.0.0.1:{find_free_port()}")
+        if self.protocol == "inproc://":
+            random_suffix = "".join(random.choices(string.ascii_letters, k=10))
+            sub = f"inproc://test-sub-{random_suffix}"
+            pub = f"inproc://test-pub-{random_suffix}"
+        else:
+            sub = f"tcp://127.0.0.1:{_find_free_port()}"
+            pub = f"tcp://127.0.0.1:{_find_free_port()}"
+
+        settings.override(
+            BROKER_SUB=sub,
+            BROKER_PUB=pub
+        )
+        self.addCleanup(settings.reset)
 
         self.zmq_broker = TestBroker(settings.BROKER_SUB, settings.BROKER_PUB)
 
         self.zmq_broker.start()
+        self.addCleanup(self.zmq_broker.stop)
+
         self.zmq_client = TestClient(self.zmq_broker)
         self.zmq_client.start()
+        self.addCleanup(self.zmq_client.stop)
 
         topics = set(self.topics + [f"rpc-rep-{x}" for x in self.rpc_channels])
         topics = [x.encode("ascii") if isinstance(x, str) else x for x in topics]
@@ -414,8 +428,7 @@ class ZMQTestMixin(TestCase):
     def zmq_context(self):
         return self.zmq_broker.context
 
-    def zmq_config(self, **kwargs):
-        settings.override(**kwargs)
+    def zmq_config(self):
         return settings
 
     def tearDown(self):
@@ -423,10 +436,8 @@ class ZMQTestMixin(TestCase):
             "testcase has no zmq_client member, did you forget to call super().setUp()?"
         )
         super(ZMQTestMixin, self).tearDown()
-        self.zmq_client.stop()
-        self.zmq_broker.stop()
         Schema.to_file()
-        settings.reset()
+
 
     def rpc(self, channel: str, type: str, request, timeout=3, receive_response=True, resource=None) -> Optional[dict]:
         response_topic = f"rpc-rep-{channel}".encode("ascii")
@@ -438,7 +449,7 @@ class ZMQTestMixin(TestCase):
 
         rpc_id = str(uuid4())
         rpc_request = _TestRPCRequest(name="testclient", type=type, rpc_id=rpc_id,
-                                      resource=resource or settings.RESOURCE, request=request)
+                                      resource=resource, request=request)
         self.zmq_client.send(f"rpc-req-{channel}".encode("ascii"), rpc_request)
         if receive_response:
             _, response = self.zmq_client.wait_for_message(
