@@ -2,7 +2,9 @@ import logging
 import time
 from unittest import TestCase
 
-from openmodule_test.interrupt import InterruptTestMixin
+from openmodule.config import settings
+from openmodule.core import init_openmodule, shutdown_openmodule
+from openmodule_test.interrupt import InterruptTestMixin, MainTestMixin
 
 
 def test():
@@ -57,3 +59,34 @@ class InterruptTimeoutTest(InterruptTestMixin, TestCase):
         with self.assertRaises(AssertionError) as e:
             self.exception_in_function(sleepy, Exception())
         self.assertIn("Thread took to long for shutdown", str(e.exception))
+
+
+def main():
+    core = init_openmodule(settings)
+    main.run = True
+    try:
+        while main.run:
+            time.sleep(1)
+        logging.info("stopped")
+    except KeyboardInterrupt:
+        logging.error("keyboard")
+    except Exception as e:
+        print(e)
+    finally:
+        shutdown_openmodule()
+
+
+class MainTest(MainTestMixin):
+    def test_keyboard(self):
+        with self.assertLogs() as cm:
+            self.exception_in_function(main, KeyboardInterrupt)
+        self.assertIn("keyboard", str(cm.output))
+
+    def test_run(self):
+        def stop(f):
+            logging.error(f)
+            f.run = False
+
+        with self.assertLogs() as cm:
+            self.custom_action_in_function(main, stop)
+        self.assertIn("stopped", str(cm.output))
\ No newline at end of file
