@@ -1,17 +1,19 @@
 import logging
+import time
 from functools import partial
 from unittest import TestCase
 from uuid import uuid4
 
 from pydantic.types import conint
 
-from openmodule.config import override_settings, override_context, settings
+from openmodule.config import settings, override_context
 from openmodule.models.base import OpenModuleModel
 from openmodule.rpc import server
+from openmodule.rpc.client import RPCClient
 from openmodule.rpc.common import channel_to_response_topic, channel_to_request_topic
 from openmodule.rpc.server import RPCServer, RPCRequest
+from openmodule_test.core import OpenModuleCoreTestMixin
 from openmodule_test.rpc import RPCServerTestMixin
-from openmodule_test.zeromq import ZMQTestMixin
 
 
 def _fake_request(gate=..., direction=...):
@@ -365,3 +367,74 @@ class RPCServerTestCase(RPCServerTestMixin):
 
         with self.assertRaises(TimeoutError):
             self.rpc("channel", "test-type", {}, resource="test-2")
+
+
+class RpcClientTest(RPCServerTestMixin, OpenModuleCoreTestMixin):
+    rpc_channels = ["channel"]
+
+    @staticmethod
+    def handler1(*_, **__):
+        """test handler"""
+        logging.info("handler 1")
+        return TestRPCResponse2(some_payload="abc")
+
+    @staticmethod
+    def timeout_handler(*_, **__):
+        """test handler"""
+        logging.info("timout_handler")
+        time.sleep(3)
+        return TestRPCResponse2(some_payload="abc")
+
+    def setUp(self):
+        super().setUp()
+        self.server = RPCServer(config=self.zmq_config(), context=self.zmq_context(), filter_resource=False)
+        self.server.register_handler("channel", "test", TestRPCRequest, TestRPCResponse2, self.handler1)
+        self.server.register_handler("channel", "timeout", TestRPCRequest, TestRPCResponse2, self.timeout_handler)
+        self.server.run_as_thread()
+        self.wait_for_rpc_server(self.server)
+
+        self.client = RPCClient(self.core, channels=[b"channel"])
+        self.wait_for_dispatcher(self.core.messages)
+
+    def test_blocking(self):
+        result = self.client.rpc(b"channel", "test", {}, timeout=1)
+        self.assertEqual("ok", result.status)
+
+        with self.assertRaises(TimeoutError):
+            result = self.client.rpc(b"channel", "timeout", {}, timeout=1)
+
+    def test_non_blocking(self):
+        result = self.client.rpc(b"channel", "test", {}, timeout=1, blocking=False)
+        self.assertEqual("ok", result.status)
+        self.assertEqual(None, result.response)
+        time.sleep(1)
+        result = self.client.check_result(result.rpc_id)
+        self.assertIsNotNone(result.response)
+        self.assertEqual("ok", result.status)
+        self.assertIn("some_payload", result.response)
+
+class RpcClientResourceTest(RPCServerTestMixin, OpenModuleCoreTestMixin):
+    rpc_channels = ["channel"]
+
+    def setUp(self):
+        super().setUp()
+        self.server = RPCServer(config=self.zmq_config(), context=self.zmq_context(), filter_resource=True)
+        self.server.register_handler("channel", "test", TestRPCRequest, TestRPCResponse2, RpcClientTest.handler1)
+        self.server.register_handler("channel", "timeout", TestRPCRequest, TestRPCResponse2, RpcClientTest.timeout_handler)
+        self.server.run_as_thread()
+        self.wait_for_rpc_server(self.server)
+
+        self.client = RPCClient(self.core, channels=[b"channel"])
+        self.wait_for_dispatcher(self.core.messages)
+
+    def test_resource_filter(self):
+        result = self.client.rpc(b"channel", "test", {}, timeout=1)
+        self.assertEqual("ok", result.status)
+
+        with override_context(RESOURCE="asdf"):
+            with self.assertRaises(TimeoutError):
+                result = self.client.rpc(b"channel", "test", {}, timeout=1)
+
+        with override_context(RESOURCE=""):
+            result = self.client.rpc(b"channel", "test", {}, timeout=1)
+            self.assertEqual("ok", result.status)
